==> viha-5.15.tar.gz: viha-5.15/laite_tyyppi.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "laite_tyyppi";
$file = basename(__FILE__);

include "common.php";
include "laite_tyyppi-ok.php";

echo "
<html>
<head>
 <title>VIHA - Viestivlineiden tyyppikoodit</title>
</head>
" . body_bgcolor() . "
<h1>Viestivlineiden tyyppikoodien ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$laite_tyyppi = get_txt('laite_tyyppi');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

if (($add != '') && saa_tehda("$file:add")) {
  $ret = laite_tyyppi_add_ok($herja,$laite_tyyppi);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "
INSERT INTO $table
SET laite_tyyppi = '$laite_tyyppi',
    ts = '$now'";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot listty.\n";
    $clear = "SISINEN";
    loki("$sql id=" . last_insert_id());
  }
  p_herja($ret,$herja);
 } # add

if (($save != '') && saa_tehda("$file:save")) {
  $ret = laite_tyyppi_save_ok($herja,$id,$laite_tyyppi);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "
UPDATE $table
SET laite_tyyppi='$laite_tyyppi',
    ts='$now'
WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = laite_tyyppi_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 } # confirm

if ($clear != '') {
  $id = '0';
  $laite_tyyppi = '';
 }

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = laite_tyyppi_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
}

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $laite_tyyppi = $a['laite_tyyppi'];
}

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Laitteen tyyppi:";
if ($readonly) {
  echo "<td>$laite_tyyppi\n";
} else {
  echo "<td><input type=\"text\" name=\"laite_tyyppi\" size=32 maxlength=32";
  echo " value=\"$laite_tyyppi\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo
      "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT $table.id, $table.ts, $table.laite_tyyppi
FROM $table
ORDER BY $table.id
";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Tyyppikoodi\n";
  while ($a = mysql_fetch_array($result)) {
    echo "<TR><TD>$a[id]", "<TD>$a[ts]", "<TD>$a[laite_tyyppi]";
    if (($id == "0") && ($a['id'] != '1')) {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
} else {
  echo "<p>Plop. Ei laitteen tyyppikooditietoja.";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: laite_tyyppi.php,v 1.8 2009/03/10 11:03:19 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/laite_tyyppi.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "laite_tyyppi";
$file = basename(__FILE__);

include "common.php";
include "laite_tyyppi-ok.php";

echo "
<html>
<head>
 <title>VIHA - Viestivlineiden tyyppikoodit</title>
</head>
" . body_bgcolor() . "
<h1>Viestivlineiden tyyppikoodien ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$laite_tyyppi = get_txt('laite_tyyppi');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

if (($add != '') && saa_tehda("$file:add")) {
  $ret = laite_tyyppi_add_ok($herja,$laite_tyyppi);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET laite_tyyppi = '$laite_tyyppi',
           ts = '$now'";
    $result = my_mysql_query ($sql);
    loki("$sql id=" . last_insert_id());
    echo "<p>Tiedot listty.\n";
    $clear = "SISINEN";
  }
  p_herja($ret,$herja);
 } # add

if (($save != '') && saa_tehda("$file:save")) {
  $ret = laite_tyyppi_save_ok($herja,$id,$laite_tyyppi);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "
UPDATE $table
SET laite_tyyppi='$laite_tyyppi',
    ts='$now'
WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = laite_tyyppi_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 } # confirm

if ($clear != '') {
  $id = '0';
  $laite_tyyppi = '';
 }

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = laite_tyyppi_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
}

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $laite_tyyppi = $a['laite_tyyppi'];
}

echo "<tr><td>Id:";
if ($id == "0") {
  echo "<td>(tehdn uusi)\n";
} else {
  echo "<td>$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Laitteen tyyppi:";
if ($readonly) {
  echo "<td>$laite_tyyppi\n";
} else {
  echo "<td><input type=\"text\" name=\"laite_tyyppi\" size=32 maxlength=32";
  echo " value=\"$laite_tyyppi\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable) {
    echo
      "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
}

$sql = "
SELECT $table.id, $table.ts, $table.laite_tyyppi
FROM $table
ORDER BY $table.id
";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Tyyppikoodi\n";
  while ($a = mysql_fetch_array($result)) {
    echo tr() . "<TD>$a[id]", "<TD>$a[ts]", "<TD>$a[laite_tyyppi]";
    if (($id == "0") && ($a['id'] != '1')) {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
} else {
  echo "<p>Plop. Ei laitteen tyyppikooditietoja.";
}

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: laite_tyyppi.php,v 1.10 2009/10/06 08:20:02 riku Exp $ -->
